@@ -44,9 +44,8 @@ class action_plugin_fckg_table extends DokuWiki_Action_Plugin {
 
       $event->data =  str_replace ( '$', '\$', $event->data);      
       preg_match('/(<table.*\/table>)/ms', $event->data, $tables); 
-              if(isset($tables[1])) {
-
-
+      if(isset($tables[1])) {
+           
               $rev_text = preg_replace_callback(            
                         "|(<td.*?>.*?</td>)|ms",
                           "td_color_spec",
@@ -62,11 +61,38 @@ class action_plugin_fckg_table extends DokuWiki_Action_Plugin {
 }
 
  // the callback function
-  function td_color_spec($matches)
-  {
+function td_color_spec($matches)
+{
 
-// Selects the first non-white indent color as cell background
-   if(preg_match_all('/<indent\s+style=\s*"color:(.*?)>/', $matches[1], $color)) {
+// Uses rgb value or else selects the first non-white indent color as cell background
+
+   $aligns = array('L'=> "left", 'R'=> "right", 'C'=> "center");
+   $col_span = preg_match('/colspan\s*=\s*[\'"]\d+[\'"]/', $matches[1], $colspan) ? $colspan[0] : "";
+   $width = "";
+   if(preg_match('/#([RLC])(rgb\(\d+,\s*\d+,\s*\d+\))(\d*px)*#/', $matches[1], $color)) {         
+        $align = $aligns[$color[1]];
+        if(isset($color[3])) {
+          $width = '; width: ' . $color[3]; 
+        }
+        return preg_replace('/<td.*?>\s*#[RLC]rgb\(\d+,\s*\d+,\s*\d+\)(\d*px)*#/', 
+              "<td  $col_span align = '$align'  style='background-color:$color[2] $width'>", $matches[1]);          
+   }
+   elseif(preg_match('/#([RLC])(\d*px)*#/', $matches[1], $alignment)) {         
+        $align = $aligns[$alignment[1]];
+        if(isset($alignment[2])) {
+          $width = " style='width: " . $alignment[2] . "';";
+        }
+        return preg_replace('/<td.*?>\s*#[RLC](\d*px)*#/', 
+              "<td $col_span align = '$align'  $width >", $matches[1]);          
+   }
+   if(preg_match('/#(rgb\(\d+,\s*\d+,\s*\d+\))(\d*px)*#/', $matches[1], $color)) {         
+        if(isset($color[2])) {
+          $width = '; width: ' . $color[2]; 
+        }
+        return preg_replace('/<td.*?>\s*#rgb\(\d+,\s*\d+,\s*\d+\)(\d*px)*#/',
+          "<td $col_span style='background-color:$color[1] $width'>", $matches[1]);          
+   }   
+   elseif(preg_match_all('/<indent\s+style=\s*"color:(.*?)>/', $matches[1], $color)) {
            if(count($color[1] > 1)) {
                 $i_colors = $color[1];
                 $i_color = "white"; 
@@ -106,7 +132,7 @@ class action_plugin_fckg_table extends DokuWiki_Action_Plugin {
    }
 
    return $matches[1];
-  }
+}
  
 
 
