@@ -94,7 +94,8 @@ FCKConfig.TemplateReplaceCheckbox = true ;
 
 FCKConfig.ToolbarLocation = 'In' ;
 
-FCKConfig.Plugins.Add( 'findreplace', 'en,it' ) ;
+//FCKConfig.Plugins.Add('freplace', 'findreplace', 'en,it' ) ;
+FCKConfig.Plugins.Add('tableformat', 'en,it' ) ;
 
 
 FCKConfig.ToolbarSets["Default"] = [
@@ -149,7 +150,7 @@ FCKConfig.BrowserContextMenuOnCtrl = false ;
 FCKConfig.EnableMoreFontColors = true ;
 FCKConfig.FontColors = '000000,993300,333300,003300,003366,000080,333399,333333,800000,FF6600,808000,808080,008080,0000FF,666699,808080,FF0000,FF9900,99CC00,339966,33CCCC,3366FF,800080,999999,FF00FF,FFCC00,FFFF00,00FF00,00FFFF,00CCFF,993366,C0C0C0,FF99CC,FFCC99,FFFF99,CCFFCC,CCFFFF,99CCFF,CC99FF,FFFFFF' ;
 
-FCKConfig.FontFormats	= 'p;h1;h2;h3;h4;h5;h6;pre;address;div' ;
+FCKConfig.FontFormats	= 'p;h1;h2;h3;h4;h5;h6;pre;address;div';
 FCKConfig.FontNames		= 'Arial;Comic Sans MS;Courier New;Tahoma;Times New Roman;Verdana;Gill Sans,Gill Sans MT,Arial;Copperplate Gothic Light,CopperplateLight;Baskerville,Baskerville Old Face;Lucida Bright;Palatino, Palatino Linotype';
 //FCKConfig.FontSizes		= 'smaller;larger;xx-small;x-small;small;medium;large;x-large;xx-large' ;
 FCKConfig.FontSizes		= '6pt;8pt;9pt;10pt;11pt;12pt;14pt;16pt;18pt;24pt;36pt' ;
@@ -224,7 +225,7 @@ FCKConfig.CoreStyles =
 	'h4'			: { Element : 'h4' },
 	'h5'			: { Element : 'h5' },
 	'h6'			: { Element : 'h6' },
-	
+ 
 	// Other formatting features.
 	'FontFace' : 
 	{ 
@@ -320,10 +321,10 @@ FCKConfig.ToolbarSets["Dokuwiki"] = [
   ['Bold','Italic','Underline','StrikeThrough','-','Subscript','Superscript'],   
   ['OrderedList','UnorderedList'],  ['Outdent','Indent'],   
   ['JustifyCenter','JustifyLeft','JustifyRight'],
-  ['Table','Rule', 'Blockquote'], ['Smiley', 'SpecialChar'], [],  
-  ['Cut','Copy','Paste','PasteText', 'PasteWord', 'SpellCheck' ],   
+  ['Rule', 'Blockquote'], ['Smiley', 'SpecialChar'], [],  
+  ['Cut','Copy','Paste','PasteText', 'PasteWord', 'SpellCheck', 'Find'],   
   ['Style'], ['FontFormat','FontName','FontSize'], 
-  ['Undo','Redo','RemoveFormat', '-','Find'],   
+  ['Undo','Redo','RemoveFormat', '-','Table','Format_Table'],   
   ['TextColor','BGColor', 'Abbr'],
   ['Link','Unlink'], ['Image', 'Source'],   
   ['About']   
